@@ -9,6 +9,13 @@
 # - This file should not override previously defined variables, as their values may
 #   originate from user changes to /etc/genkernel.conf .
 
+GKPKG_B2_PN="b2"
+GKPKG_B2_PV="${GKPKG_B2_PV:-${VERSION_B2}}"
+GKPKG_B2_DEPS=""
+GKPKG_B2_SRCTAR="${GKPKG_B2_SRCTAR:-${DISTDIR}/b2-${GKPKG_B2_PV}.tar.gz}"
+GKPKG_B2_SRCDIR="${GKPKG_3_SRCDIR:-b2-${GKPKG_B2_PV}}"
+GKPKG_B2_BINPKG="${GKPKG_B2_BINPKG:-%%CACHE%%/b2-${GKPKG_B2_PV}.tar.xz}"
+
 GKPKG_BCACHE_TOOLS_PN="bcache-tools"
 GKPKG_BCACHE_TOOLS_PV="${GKPKG_BCACHE_TOOLS_PV:-${VERSION_BCACHE_TOOLS}}"
 GKPKG_BCACHE_TOOLS_DEPS="util-linux eudev"
@@ -18,18 +25,11 @@ GKPKG_BCACHE_TOOLS_BINPKG="${GKPKG_BCACHE_TOOLS_BINPKG:-%%CACHE%%/bcache-tools-$
 
 GKPKG_BOOST_PN="boost"
 GKPKG_BOOST_PV="${GKPKG_BOOST_PV:-${VERSION_BOOST}}"
-GKPKG_BOOST_DEPS="boost-build"
+GKPKG_BOOST_DEPS="b2"
 GKPKG_BOOST_SRCTAR="${GKPKG_BOOST_SRCTAR:-${DISTDIR}/boost_${GKPKG_BOOST_PV//./_}.tar.bz2}"
 GKPKG_BOOST_SRCDIR="${GKPKG_BOOST_SRCDIR:-boost_${GKPKG_BOOST_PV//./_}}"
 GKPKG_BOOST_BINPKG="${GKPKG_BOOST_BINPKG:-%%CACHE%%/boost-${GKPKG_BOOST_PV}-%%ARCH%%.tar.xz}"
 
-GKPKG_BOOST_BUILD_PN="boost-build"
-GKPKG_BOOST_BUILD_PV="${GKPKG_BOOST_PV}"
-GKPKG_BOOST_BUILD_DEPS=""
-GKPKG_BOOST_BUILD_SRCTAR="${GKPKG_BOOST_SRCTAR}"
-GKPKG_BOOST_BUILD_SRCDIR="${GKPKG_BOOST_SRCDIR}"
-GKPKG_BOOST_BUILD_BINPKG="${GKPKG_BOOST_BUILD_BINPKG:-%%CACHE%%/boost-build-${GKPKG_BOOST_BUILD_PV}.tar.xz}"
-
 GKPKG_BTRFS_PROGS_PN="btrfs-progs"
 GKPKG_BTRFS_PROGS_PV="${GKPKG_BTRFS_PROGS_PV:-${VERSION_BTRFS_PROGS}}"
 GKPKG_BTRFS_PROGS_DEPS="util-linux zlib zstd lzo eudev"
